==> element-ui-1.3.1.jar: META-INF/resources/webjars/element-ui/1.3.1/lib/umd/locale/tk.js <==
(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define('element/locale/tk', ['module', 'exports'], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.ELEMENT.lang = global.ELEMENT.lang || {}; 
    global.ELEMENT.lang.tk = mod.exports;
  }
})(this, function (module, exports) {
  'use strict';

  exports.__esModule = true;
  exports.default = {
    el: {
      colorpicker: {
        confirm: 'OK',
        clear: 'Arassala'
      },
      datepicker: {
        now: 'Ýaňy',
        today: 'Şügün',
        cancel: 'Bes et',
        clear: 'Arassala',
        confirm: 'OK',
        selectDate: 'Güni saýlaň',
        selectTime: 'Wagty saýlaň',
        startDate: 'Başlaýan Güni',
        startTime: 'Başlaýan Wagty',
        endDate: 'Sonky Güni',
        endTime: 'Sonky Wagty',
        year: '',
        month1: 'Ýan',
        month2: 'Few',
        month3: 'Mar',
        month4: 'Apr',
        month5: 'Maý',
        month6: 'Iýn',
        month7: 'Iýl',
        month8: 'Awg',
        month9: 'Sep',
        month10: 'Okt',
        month11: 'Noý',
        month12: 'Dek',
        // week: 'week',
        weeks: {
          sun: 'Ýek',
          mon: 'Duş',
          tue: 'Siş',
          wed: 'Çar',
          thu: 'Pen',
          fri: 'Ann',
          sat: 'Şen'
        },
        months: {
          jan: 'Ýan',
          feb: 'Few',
          mar: 'Mar',
          apr: 'Apr',
          may: 'Maý',
          jun: 'Iýn',
          jul: 'Iýl',
          aug: 'Awg',
          sep: 'Sep',
          oct: 'Okt',
          nov: 'Noý',
          dec: 'Dek'
        }
      },
      select: {
        loading: 'Indirilýär',
        noMatch: 'Hiçzat tapylmady',
        noData: 'Hiçzat ýok',
        placeholder: 'Saýla'
      },
      cascader: {
        noMatch: 'Hiçzat tapylmady',
        placeholder: 'saýlaň'
      },
      pagination: {
        goto: 'Git',
        pagesize: '/sahypa',
        total: 'Umumy {total}',
        pageClassifier: ''
      },
      messagebox: {
        title: 'Hat',
        confirm: 'OK',
        cancel: 'Bes et',
        error: 'Ýalňyş girizme'
      },
      upload: {
        delete: 'Poz',
        preview: 'Gör',
        continue: 'Dowam et'
      },
      table: {
        emptyText: 'Maglumat ýok',
        confirmFilter: 'Tassykla',
        resetFilter: 'Arassala',
        clearFilter: 'Hemmesi',
        sumText: 'Sum' // to be translated
      },
      tree: {
        emptyText: 'Maglumat ýok'
      },
      transfer: {
        noMatch: 'Hiçzat tapylmady',
        noData: 'Hiçzat ýok',
        titles: ['List 1', 'List 2'], // to be translated
        filterPlaceholder: 'Enter keyword', // to be translated
        noCheckedFormat: '{total} items', // to be translated
        hasCheckedFormat: '{checked}/{total} checked' // to be translated
      }
    }
  };
  module.exports = exports['default'];
});

==> element-ui-2.0.0-rc.1.jar: META-INF/resources/webjars/element-ui/2.0.0-rc.1/lib/umd/locale/tk.js <==
(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define('element/locale/tk', ['module', 'exports'], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.ELEMENT.lang = global.ELEMENT.lang || {}; 
    global.ELEMENT.lang.tk = mod.exports;
  }
})(this, function (module, exports) {
  'use strict';

  exports.__esModule = true;
  exports.default = {
    el: {
      colorpicker: {
        confirm: 'OK',
        clear: 'Arassala'
      },
      datepicker: {
        now: 'Şuwagt',
        today: 'Şügün',
        cancel: 'Bes et',
        clear: 'Arassala',
        confirm: 'OK',
        selectDate: 'Güni saýlaň',
        selectTime: 'Wagty saýlaň',
        startDate: 'Başlaýan güni',
        startTime: 'Başlaýan wagty',
        endDate: 'Gutarýan güni',
        endTime: 'Gutarýan wagty',
        year: '',
        month1: 'Ýan',
        month2: 'Few',
        month3: 'Mar',
        month4: 'Apr',
        month5: 'Maý',
        month6: 'Iýn',
        month7: 'Iýl',
        month8: 'Awg',
        month9: 'Sen',
        month10: 'Okt',
        month11: 'Noý',
        month12: 'Dek',
        // week: 'week',
        weeks: {
          sun: 'Ýek',
          mon: 'Duş',
          tue: 'Siş',
          wed: 'Çar',
          thu: 'Pen',
          fri: 'Ann',
          sat: 'Şen'
        },
        months: {
          jan: 'Ýan',
          feb: 'Few',
          mar: 'Mar',
          apr: 'Apr',
          may: 'Maý',
          jun: 'Iýn',
          jul: 'Iýl',
          aug: 'Awg',
          sep: 'Sep',
          oct: 'Okt',
          nov: 'Noý',
          dec: 'Dek'
        }
      },
      select: {
        loading: 'Indirilýär',
        noMatch: 'Hiçzat tapylmady',
        noData: 'Hiçzat ýok',
        placeholder: 'Saýla'
      },
      cascader: {
        noMatch: 'Hiçzat tapylmady',
        loading: 'Indirilýär',
        placeholder: 'Saýlaň'
      },
      pagination: {
        goto: 'Git',
        pagesize: '/sahypa',
        total: 'Umumy {total}',
        pageClassifier: ''
      },
      messagebox: {
        title: 'Hat',
        confirm: 'OK',
        cancel: 'Bes et',
        error: 'Ýalňyş girizme'
      },
      upload: {
        deleteTip: 'Pozmak üçin "poz" düwmä basyň',
        delete: 'Poz',
        preview: 'Gör',
        continue: 'Dowam et'
      },
      table: {
        emptyText: 'Maglumat ýok',
        confirmFilter: 'Tassykla',
        resetFilter: 'Arassala',
        clearFilter: 'Hemmesi',
        sumText: 'Jemi'
      },
      tree: {
        emptyText: 'Maglumat ýok'
      },
      transfer: {
        noMatch: 'Hiçzat tapylmady',
        noData: 'Hiçzat ýok',
        titles: ['Sanaw 1', 'Sanaw 2'],
        filterPlaceholder: 'Gözleg sözlerini giriziň',
        noCheckedFormat: '{total} sany',
        hasCheckedFormat: '{checked}/{total} saýlanan'
      }
    }
  };
  module.exports = exports['default'];
});
